@@ -105,6 +105,7 @@ class ClickReview(object):
                        "kernel",
                        "modules",
                        "oem",
+                       "gadget",
                        "services",
                        "source",
                        "type",
@@ -114,6 +115,12 @@ class ClickReview(object):
                            "security-template",
                            "security-override",
                            "security-policy"]
+    magic_binary_file_descriptions = [
+        'application/x-executable; charset=binary',
+        'application/x-sharedlib; charset=binary',
+        'application/x-object; charset=binary',
+        'application/octet-stream; charset=binary'
+    ]
 
     def __init__(self, fn, review_type, peer_hooks=None, overrides=None,
                  peer_hooks_link=None):
@@ -154,8 +161,9 @@ class ClickReview(object):
 
         # Parse and store the package.yaml, if it exists
         pkg_yaml = self._extract_package_yaml()
+        snap_yaml = self._extract_snap_yaml()
         self.is_snap = False
-        if pkg_yaml is None:
+        if pkg_yaml is None and snap_yaml is None:
             self.pkgfmt["type"] = "click"
         else:
             self.pkgfmt["type"] = "snap"
@@ -169,11 +177,23 @@ class ClickReview(object):
             else:
                 self.pkgfmt["version"] = "15.04"
 
-            try:
-                self.pkg_yaml = yaml.safe_load(pkg_yaml)
-            except Exception:
-                error("Could not load package.yaml. Is it properly formatted?")
-            self._verify_package_yaml_structure()
+            if snap_yaml:
+                try:
+                    self.snap_yaml = yaml.safe_load(snap_yaml)
+                except Exception:
+                    error("Could not load snap.yaml. Is it properly formatted?")
+                # convert enough of snap_yaml too pkg.yaml to make
+                # the basics of the review tools
+                if self.snap_yaml:
+                    self.pkg_yaml = self.snap_yaml
+                    self.pkg_yaml["version"] = str(self.snap_yaml["version"])
+
+            if pkg_yaml:
+                try:
+                    self.pkg_yaml = yaml.safe_load(pkg_yaml)
+                except Exception:
+                    error("Could not load package.yaml. Is it properly formatted?")
+                self._verify_package_yaml_structure()
             self.is_snap = True
 
             #  default to 'app'
@@ -224,6 +244,11 @@ class ClickReview(object):
            self.pkg_yaml['type'] == 'oem':
             self.is_snap_oem = True
 
+        self.is_snap_gadget = False
+        if self.is_snap and 'type' in self.pkg_yaml and \
+           self.pkg_yaml['type'] == 'gadget':
+            self.is_snap_gadget = True
+
         # Get a list of all unpacked files, except DEBIAN/
         self.pkg_files = []
         self._list_all_files()
@@ -260,12 +285,19 @@ class ClickReview(object):
         return open_file_read(m)
 
     def _extract_package_yaml(self):
-        '''Extract and read the snappy package.yaml'''
+        '''Extract and read the snappy 15.04 package.yaml'''
         y = os.path.join(self.unpack_dir, "meta/package.yaml")
         if not os.path.isfile(y):
             return None  # snappy packaging is still optional
         return open_file_read(y)
 
+    def _extract_snap_yaml(self):
+        '''Extract and read the snappy 16.04 snap.yaml'''
+        y = os.path.join(self.unpack_dir, "meta/snap.yaml")
+        if not os.path.isfile(y):
+            return None  # snappy packaging is still optional
+        return open_file_read(y)
+
     def _extract_hashes_yaml(self):
         '''Extract and read the snappy hashes.yaml'''
         y = os.path.join(self.unpack_dir, "DEBIAN/hashes.yaml")
@@ -317,14 +349,18 @@ class ClickReview(object):
             for f in filenames:
                 self.pkg_files.append(os.path.join(root, f))
 
+    def _check_if_message_catalog(self, fn):
+        '''Check if file is a message catalog (.mo file).'''
+        if fn.endswith('.mo'):
+            return True
+        return False
+
     def _list_all_compiled_binaries(self):
         '''List all compiled binaries in this click package.'''
         for i in self.pkg_files:
             res = self.mime.file(i)
-            if res in ['application/x-executable; charset=binary',
-                       'application/x-sharedlib; charset=binary',
-                       'application/x-object; charset=binary',
-                       'application/octet-stream; charset=binary']:
+            if res in self.magic_binary_file_descriptions and \
+               not self._check_if_message_catalog(i):
                 self.pkg_bin_files.append(i)
 
     def _verify_manifest_structure(self):
