@@ -131,36 +131,79 @@ class ClickReviewSecurity(ClickReview):
         framework_overrides = self.overrides.get('framework', {})
         self._override_framework_policies(framework_overrides)
 
+        # snappy
+        self.sec_skipped_types = ['oem',
+                                  'os',
+                                  'kernel']  # these don't need security items
+
         self.security_manifests = dict()
         self.security_apps = []
-        for app in self.manifest['hooks']:
-            if 'apparmor' not in self.manifest['hooks'][app]:
-                #  msg("Skipped missing apparmor hook for '%s'" % app)
-                continue
-            if not isinstance(self.manifest['hooks'][app]['apparmor'], str):
-                error("manifest malformed: hooks/%s/apparmor is not str" % app)
-            rel_fn = self.manifest['hooks'][app]['apparmor']
-            self.security_manifests[rel_fn] = \
-                self._extract_security_manifest(app)
-            self.security_apps.append(app)
-
         self.security_profiles = dict()
         self.security_apps_profiles = []
-        for app in self.manifest['hooks']:
-            if 'apparmor-profile' not in self.manifest['hooks'][app]:
-                #  msg("Skipped missing apparmor hook for '%s'" % app)
-                continue
-            if not isinstance(self.manifest['hooks'][app]['apparmor-profile'],
-                              str):
-                error("manifest malformed: hooks/%s/apparmor-profile is not "
-                      "str" % app)
-            rel_fn = self.manifest['hooks'][app]['apparmor-profile']
-            self.security_profiles[rel_fn] = \
-                self._extract_security_profile(app)
-            self.security_apps_profiles.append(app)
 
-        # snappy
-        self.sec_skipped_types = ['oem']  # these don't need security items
+        if self.manifest is None and self.is_snap:
+            for exe_t in ['services', 'binaries']:
+                if exe_t not in self.pkg_yaml:
+                    continue
+                for item in self.pkg_yaml[exe_t]:
+                    if 'name' not in item:
+                        continue
+                    app = "%s/%s" % (exe_t, item['name'])
+
+                    if 'security-policy' in item:
+                        if 'apparmor' not in item['security-policy']:
+                            continue
+                        rel_fn = item['security-policy']['apparmor']
+                        self.security_profiles[rel_fn] = \
+                            self._extract_security_profile(app)
+                        self.security_apps_profiles.append(app)
+                        continue
+
+                    # Fake a security manifest for code reuse
+                    # FIXME: this needs to be updated when we have 'target'
+                    m = dict()
+                    m['policy_vendor'] = "ubuntu-core"
+                    m['policy_version'] = self._pkgfmt_version()
+                    if 'security-template' in item:
+                        m['template'] = item['security-template']
+                    else:
+                        m['template'] = 'default'
+
+                    if 'caps' in item:
+                        m['policy_groups'] = item['caps']
+                    elif self._pkgfmt_version() == "15.04":
+                        m['policy_groups'] = ['networking']
+                    else:
+                        m['policy_groups'] = ['network-client']
+
+                    self.security_manifests[app] = m
+                    self.security_apps.append(app)
+        else:
+            self.security_manifests = dict()
+            self.security_apps = []
+            for app in self.manifest['hooks']:
+                if 'apparmor' not in self.manifest['hooks'][app]:
+                    #  msg("Skipped missing apparmor hook for '%s'" % app)
+                    continue
+                if not isinstance(self.manifest['hooks'][app]['apparmor'], str):
+                    error("manifest malformed: hooks/%s/apparmor is not str" % app)
+                rel_fn = self.manifest['hooks'][app]['apparmor']
+                self.security_manifests[rel_fn] = \
+                    self._extract_security_manifest(app)
+                self.security_apps.append(app)
+
+            for app in self.manifest['hooks']:
+                if 'apparmor-profile' not in self.manifest['hooks'][app]:
+                    #  msg("Skipped missing apparmor hook for '%s'" % app)
+                    continue
+                if not isinstance(self.manifest['hooks'][app]['apparmor-profile'],
+                                  str):
+                    error("manifest malformed: hooks/%s/apparmor-profile is not "
+                          "str" % app)
+                rel_fn = self.manifest['hooks'][app]['apparmor-profile']
+                self.security_profiles[rel_fn] = \
+                    self._extract_security_profile(app)
+                self.security_apps_profiles.append(app)
 
     def _override_framework_policies(self, overrides):
         # override major framework policies
@@ -222,21 +265,32 @@ class ClickReviewSecurity(ClickReview):
 
     def _get_security_manifest(self, app):
         '''Get the security manifest for app'''
-        if app not in self.manifest['hooks']:
-            error("Could not find '%s' in click manifest" % app)
-        elif 'apparmor' not in self.manifest['hooks'][app]:
-            error("Could not find apparmor hook for '%s' in click manifest" %
-                  app)
-        f = self.manifest['hooks'][app]['apparmor']
-        m = self.security_manifests[f]
+        if self._pkgfmt_type() == "click" or self._pkgfmt_version() == "15.04":
+            if app not in self.manifest['hooks']:
+                error("Could not find '%s' in click manifest" % app)
+            elif 'apparmor' not in self.manifest['hooks'][app]:
+                error("Could not find apparmor hook for '%s' in click manifest" %
+                      app)
+            f = self.manifest['hooks'][app]['apparmor']
+            m = self.security_manifests[f]
+        else:
+            f = app
+            m = self.security_manifests[app]
+
         return (f, m)
 
     def _extract_security_profile(self, app):
         '''Extract security profile'''
-        d = self.manifest['hooks'][app]['apparmor-profile']
-        fn = os.path.join(self.unpack_dir, d)
-        rel_fn = self.manifest['hooks'][app]['apparmor-profile']
+        if self._pkgfmt_type() == "click" or self._pkgfmt_version() == "15.04":
+            rel_fn = self.manifest['hooks'][app]['apparmor-profile']
+        else:
+            exe_t, name = app.split('/')
+            for item in self.pkg_yaml[exe_t]:
+                if 'name' in item and item['name'] == name:
+                    rel_fn = item['security-policy']['apparmor']
+                    break
 
+        fn = os.path.join(self.unpack_dir, rel_fn)
         if not os.path.exists(fn):
             error("Could not find '%s'" % rel_fn)
 
@@ -254,12 +308,20 @@ class ClickReviewSecurity(ClickReview):
 
     def _get_security_profile(self, app):
         '''Get the security profile for app'''
-        if app not in self.manifest['hooks']:
-            error("Could not find '%s' in click manifest" % app)
-        elif 'apparmor-profile' not in self.manifest['hooks'][app]:
-            error("Could not find apparmor-profile hook for '%s' in click "
-                  "manifest" % app)
-        f = self.manifest['hooks'][app]['apparmor-profile']
+        if self._pkgfmt_type() == "click" or self._pkgfmt_version() == "15.04":
+            if app not in self.manifest['hooks']:
+                error("Could not find '%s' in click manifest" % app)
+            elif 'apparmor-profile' not in self.manifest['hooks'][app]:
+                error("Could not find apparmor-profile hook for '%s' in click "
+                      "manifest" % app)
+            f = self.manifest['hooks'][app]['apparmor-profile']
+        else:
+            exe_t, name = app.split('/')
+            for item in self.pkg_yaml[exe_t]:
+                if 'name' in item and item['name'] == name:
+                    f = item['security-policy']['apparmor']
+                    break
+
         p = self.security_profiles[f]
         return (f, p)
 
@@ -343,6 +405,10 @@ class ClickReviewSecurity(ClickReview):
                 s = "policy_vendor '%s' not found" % m['policy_vendor']
             self._add_result(t, n, s)
 
+            if self._pkgfmt_type() == "snap" and \
+                    float(self._pkgfmt_version()) >= 16.04:
+                continue
+
             t = 'info'
             n = self._get_check_name('policy_vendor_matches_framework', extra=f)
             s = "OK"
@@ -408,6 +474,10 @@ class ClickReviewSecurity(ClickReview):
                 s = '%s != %s' % (str(m['policy_version']), str(highest))
             self._add_result(t, n, s, l)
 
+            if self._pkgfmt_type() == "snap" and \
+                    float(self._pkgfmt_version()) >= 16.04:
+                continue
+
             t = 'info'
             n = self._get_check_name('policy_version_matches_framework', extra=f)
             s = "OK"
@@ -425,13 +495,14 @@ class ClickReviewSecurity(ClickReview):
                 found_major = True
                 if m['policy_version'] != data['policy_version']:
                     t = 'error'
+                    l = 'http://askubuntu.com/q/686347'
                     s = '%s != %s (%s)' % (str(m['policy_version']),
                                            data['policy_version'],
                                            framework)
             if not found_major:
                 t = 'error'
                 s = "Invalid framework '%s'" % framework
-            self._add_result(t, n, s)
+            self._add_result(t, n, s, l)
 
     def check_template(self):
         '''Check template'''
@@ -450,6 +521,7 @@ class ClickReviewSecurity(ClickReview):
             t = 'info'
             n = self._get_check_name('template_valid', extra=f)
             s = "OK"
+            l = 'http://askubuntu.com/q/671403'
             manual_review = False
             if 'template' not in m:
                 # If template not specified, we just use the default
@@ -457,13 +529,13 @@ class ClickReviewSecurity(ClickReview):
                 continue
             elif m['template'] in self.redflag_templates:
                 t = 'error'
-                s = "(MANUAL REVIEW) '%s' not allowed" % m['template']
+                s = "(NEEDS REVIEW) '%s' not allowed" % m['template']
                 manual_review = True
             elif ('policy_vendor' not in m or m['policy_vendor'] == 'ubuntu') \
                     and m['template'] in self.extraneous_ubuntu_templates:
                 t = 'warn'
                 s = "No need to specify '%s' template" % m['template']
-            self._add_result(t, n, s, manual_review=manual_review)
+            self._add_result(t, n, s, l, manual_review=manual_review)
 
             t = 'info'
             n = self._get_check_name('template_exists', extra=f)
@@ -543,29 +615,17 @@ class ClickReviewSecurity(ClickReview):
 
             self._add_result(t, n, s)
 
-    def check_template_push_helpers(self):
-        '''Check template for push-helpers'''
-        for app in sorted(self.security_apps):
-            (f, m) = self._get_security_manifest(app)
-            t = 'info'
-            n = self._get_check_name('template_push_helper', extra=f)
-            s = "OK"
-            if 'push-helper' not in self.manifest['hooks'][app]:
-                continue
-            if 'template' not in m or m['template'] != "ubuntu-push-helper":
-                t = 'error'
-                s = "template is not 'ubuntu-push-helper'"
-            self._add_result(t, n, s)
-
     def check_policy_groups_push_helpers(self):
-        '''Check policy_groups for push-helpers'''
+        '''Check policy groups for push-helpers'''
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
             n = self._get_check_name('policy_groups_push_helper', extra=f)
             s = "OK"
-            if 'push-helper' not in self.manifest['hooks'][app]:
+
+            if 'template' not in m or m['template'] != 'ubuntu-push-helper':
                 continue
+
             if 'policy_groups' not in m or \
                'push-notification-client' not in m['policy_groups']:
                 self._add_result('error', n,
@@ -576,7 +636,7 @@ class ClickReviewSecurity(ClickReview):
             for p in m['policy_groups']:
                 if p not in self.allowed_push_helper_policy_groups:
                     bad.append(p)
-                elif p == "networking":
+                elif p == "networking" or p == "network-client":
                     # The above covers this, but let's be very explicit and
                     # never allow networking with push-helpers
                     bad.append(p)
@@ -622,7 +682,8 @@ class ClickReviewSecurity(ClickReview):
         '''Check policy_groups for ubuntu-account-plugin template'''
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
-            if 'account-qml-plugin' not in self.manifest['hooks'][app]:
+
+            if 'template' not in m or m['template'] != 'ubuntu-account-plugin':
                 continue
 
             t = 'info'
@@ -765,7 +826,7 @@ class ClickReviewSecurity(ClickReview):
                             "'%s': not for production use" % (i)
                     elif aa_type == "reserved":
                         t = 'error'
-                        s = "(MANUAL REVIEW) %s policy group " % aa_type + \
+                        s = "(NEEDS REVIEW) %s policy group " % aa_type + \
                             "'%s': vetted applications only" % (i)
                         if i == "debug":
                             l = 'http://askubuntu.com/a/562123/94326'
@@ -841,12 +902,17 @@ class ClickReviewSecurity(ClickReview):
         for app in sorted(self.security_apps_profiles):
             (f, p) = self._get_security_profile(app)
 
-            for v in ['###VAR###',
-                      '###PROFILEATTACH###',
-                      '@{CLICK_DIR}',
-                      '@{APP_PKGNAME}',
-                      '@{APP_VERSION}',
-                      ]:
+            searches = ['###VAR###',
+                        '###PROFILEATTACH###',
+                        '@{CLICK_DIR}',
+                        '@{APP_PKGNAME}',
+                        '@{APP_VERSION}',
+                        ]
+            if self._pkgfmt_type() == 'snap' and \
+                    float(self._pkgfmt_version()) > 15.04:
+                searches.append("@{INSTALL_DIR}")
+
+            for v in searches:
                 t = 'info'
                 n = self._get_check_name(
                     'apparmor_profile', extra='%s (%s)' % (v, f))
@@ -882,6 +948,7 @@ class ClickReviewSecurity(ClickReview):
                 second = yaml
                 first_m = "click-manifest"
                 second_m = "package.yaml"
+
             for exe_t in ['binaries', 'services']:
                 t = 'info'
                 n = self._get_check_name('yaml_%s' % exe_t)
@@ -937,7 +1004,7 @@ class ClickReviewSecurity(ClickReview):
                         # manifest, unless security-template is in yaml
                         t = 'error'
                         s = "'policy_groups' not found in click manifest " + \
-                            "(should default to ['networking'])"
+                            "(should default to ['network-client'])"
                         self._add_result(t, n, s)
                         continue
                     self._add_result(t, n, s)
@@ -979,9 +1046,10 @@ class ClickReviewSecurity(ClickReview):
                             elif key == 'caps' and second == yaml and \
                                     'security-template' not in sapp and \
                                     key not in sapp and key in fapp and \
-                                    fapp[key] == set(['networking']):
+                                    (fapp[key] == set(['networking']) or
+                                     fapp[key] == set(['network-client'])):
                                 # no caps in yaml, policy_groups is networking
-                                # in click manifest wen security-template not
+                                # in click manifest when security-template not
                                 # specified in yaml
                                 self._add_result(t, n, s)
                                 continue
@@ -1077,7 +1145,9 @@ class ClickReviewSecurity(ClickReview):
         '''Verify click and security yaml are in sync (not including
            override)
         '''
-        if not self.is_snap or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_snap or \
+                self.pkg_yaml['type'] in self.sec_skipped_types or \
+                float(self._pkgfmt_version()) > 15.04:
             return
 
         # setup a small dict that is a subset of self.pkg_yaml
@@ -1117,7 +1187,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_security_yaml_override_and_click(self):
         '''Verify click and security yaml override are in sync'''
-        if not self.is_snap or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_snap or \
+                self.pkg_yaml['type'] in self.sec_skipped_types or \
+                float(self._pkgfmt_version()) > 15.04:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1176,16 +1248,44 @@ class ClickReviewSecurity(ClickReview):
                 s = "OK"
                 if 'security-override' not in item:
                     s = "OK (skipping unspecified override)"
-                elif 'apparmor' not in item['security-override']:
-                    t = 'error'
-                    s = "'apparmor' not specified in 'security-override' " + \
-                        "for '%s'" % app
-                elif 'seccomp' not in item['security-override']:
-                    t = 'error'
-                    s = "'seccomp' not specified in 'security-override' " + \
-                        "for '%s'" % app
+                elif float(self._pkgfmt_version()) < 16.04:
+                    if 'apparmor' not in item['security-override']:
+                        t = 'error'
+                        s = "'apparmor' not specified in 'security-override' " + \
+                            "for '%s'" % app
+                    elif 'seccomp' not in item['security-override']:
+                        t = 'error'
+                        s = "'seccomp' not specified in 'security-override' " + \
+                            "for '%s'" % app
+                else:
+                    allowed_fields = ['read-paths',
+                                      'write-paths',
+                                      'abstractions',
+                                      'syscalls']
+                    if len(item['security-override'].keys()) == 0:
+                        t = 'error'
+                        s = "nothing specified in 'security-override' " + \
+                            "for '%s'" % app
+                    else:
+                        for f in item['security-override'].keys():
+                            if f not in allowed_fields:
+                                t = 'error'
+                                s = "unknown field '%s' in " % f + \
+                                    "'security-override' for '%s'" % app
+
                 self._add_result(t, n, s)
 
+                # security-override on 16.04 gives direct access to syscalls,
+                # read-paths, etc so it always needs a manual override
+                if 'security-override' in item and \
+                        float(self._pkgfmt_version()) > 15.04:
+                    t = 'error'
+                    n = self._get_check_name('yaml_override_present')
+                    s = "(NEEDS REVIEW) 'security-override' not allowed"
+                    l = 'https://developer.ubuntu.com/en/snappy/guides/security-policy/'
+                    m = True
+                    self._add_result(t, n, s, link=l, manual_review=m)
+
     def check_security_yaml_policy(self):
         '''Verify security yaml policy'''
         if not self.is_snap:
@@ -1223,7 +1323,7 @@ class ClickReviewSecurity(ClickReview):
                 if 'security-policy' in item:
                     t = 'error'
                     n = self._get_check_name('yaml_policy_present')
-                    s = "(MANUAL REVIEW) 'security-policy' not allowed"
+                    s = "(NEEDS REVIEW) 'security-policy' not allowed"
                     l = 'https://developer.ubuntu.com/en/snappy/guides/security-policy/'
                     m = True
                     self._add_result(t, n, s, link=l, manual_review=m)
@@ -1301,20 +1401,21 @@ class ClickReviewSecurity(ClickReview):
                     continue
                 self._add_result(t, n, s)
 
-                t = 'info'
-                n = self._get_check_name('yaml_security-template_in_manifest', app=app)
-                s = "OK"
-                if app not in self.manifest['hooks']:
-                    t = 'error'
-                    s = "'%s' not found in click manifest" % app
-                    self._add_result(t, n, s)
-                    continue
-                elif 'apparmor' not in self.manifest['hooks'][app] and \
-                     'apparmor-profile' not in self.manifest['hooks'][app]:
-                    t = 'error'
-                    s = "'apparmor' not found in click manifest for '%s'" % app
-                    self._add_result(t, n, s)
-                    continue
+                if self._pkgfmt_version() == "15.04":
+                    t = 'info'
+                    n = self._get_check_name('yaml_security-template_in_manifest', app=app)
+                    s = "OK"
+                    if app not in self.manifest['hooks']:
+                        t = 'error'
+                        s = "'%s' not found in click manifest" % app
+                        self._add_result(t, n, s)
+                        continue
+                    elif 'apparmor' not in self.manifest['hooks'][app] and \
+                         'apparmor-profile' not in self.manifest['hooks'][app]:
+                        t = 'error'
+                        s = "'apparmor' not found in click manifest for '%s'" % app
+                        self._add_result(t, n, s)
+                        continue
 
         # TODO: error if not 'common' or is 'unconfined'
 
@@ -1354,25 +1455,30 @@ class ClickReviewSecurity(ClickReview):
                     continue
                 self._add_result(t, n, s)
 
-                t = 'info'
-                n = self._get_check_name('yaml_caps_in_manifest', app=app)
-                s = "OK"
-                if app not in self.manifest['hooks']:
-                    t = 'error'
-                    s = "'%s' not found in click manifest" % app
-                    self._add_result(t, n, s)
-                    continue
-                elif 'apparmor' not in self.manifest['hooks'][app] and \
-                     'apparmor-profile' not in self.manifest['hooks'][app]:
-                    t = 'error'
-                    s = "'apparmor' not found in click manifest for '%s'" % app
-                    self._add_result(t, n, s)
-                    continue
+                if self._pkgfmt_version() == "15.04":
+                    t = 'info'
+                    n = self._get_check_name('yaml_caps_in_manifest', app=app)
+                    s = "OK"
+                    if app not in self.manifest['hooks']:
+                        t = 'error'
+                        s = "'%s' not found in click manifest" % app
+                        self._add_result(t, n, s)
+                        continue
+                    elif 'apparmor' not in self.manifest['hooks'][app] and \
+                         'apparmor-profile' not in self.manifest['hooks'][app]:
+                        t = 'error'
+                        s = "'apparmor' not found in click manifest for '%s'" % app
+                        self._add_result(t, n, s)
+                        continue
 
         # TODO: error if not 'common'
 
     def check_template_online_accounts_provider(self):
         '''Check template for online accounts account-provider'''
+        if self._pkgfmt_type() == "snap" and \
+                float(self._pkgfmt_version()) > 15.04:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
@@ -1387,6 +1493,10 @@ class ClickReviewSecurity(ClickReview):
 
     def check_template_online_accounts_qml_plugin(self):
         '''Check template for online accounts account-qml-plugin'''
+        if self._pkgfmt_type() == "snap" and \
+                float(self._pkgfmt_version()) > 15.04:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
@@ -1398,3 +1508,42 @@ class ClickReviewSecurity(ClickReview):
                 t = 'error'
                 s = "template is not 'ubuntu-account-plugin'"
             self._add_result(t, n, s)
+
+    def check_apparmor_profile_name_length(self):
+        '''Check AppArmor profile name length'''
+        # There are quite a few kernel interfaces that can cause problems with
+        # long profile names. These are outlined in
+        # https://launchpad.net/bugs/1499544. The big issue is that the audit
+        # message must fit within PAGE_SIZE (at least 4096 on supported archs),
+        # so long names could push the audit message to be too big, which would
+        # result in a denial for that rule (but, only if the rule would've
+        # allowed it). Giving a hard-error on maxlen since we know that this
+        # will be a problem. The advisory length is what it is since we know
+        # that compound labels are sometimes logged and so a snappy system
+        # running an app in a snappy container or a QA testbed running apps
+        # under LXC
+        maxlen = 230  # 245 minus a bit for child profiles
+        advlen = 100
+        for app in sorted(self.security_apps):
+            (f, m) = self._get_security_manifest(app)
+            t = 'info'
+            n = self._get_check_name('profile_name_length', extra=f)
+            s = "OK"
+            profile = "%s_%s_%s" % (self.click_pkgname, app,
+                                    self.click_version)
+            if len(profile) > maxlen:
+                t = 'error'
+                s = ("'%s' too long (exceeds %d characters). Please shorten "
+                     "'%s', '%s' and/or '%s'" % (profile, maxlen,
+                                                 self.click_pkgname, app,
+                                                 self.click_version))
+            elif len(profile) > advlen:
+                t = 'warn'
+                s = ("'%s' is long (exceeds %d characters) and thus could be "
+                     "problematic in certain environments. Please consider "
+                     "shortening '%s', '%s' and/or '%s'" % (profile, advlen,
+                                                            self.click_pkgname,
+                                                            app,
+                                                            self.click_version)
+                     )
+            self._add_result(t, n, s)
