@@ -22,11 +22,6 @@ import lxml.etree as etree
 
 class TestClickReviewAccounts(cr_tests.TestClickReview):
     """Tests for the lint review tool."""
-    def setUp(self):
-        # Monkey patch various file access classes. stop() is handled with
-        # addCleanup in super()
-        cr_tests.mock_patch()
-        super()
 
     def _stub_application(self, root=None, id=None, do_subtree=True):
         '''Stub application xml'''
@@ -87,7 +82,7 @@ class TestClickReviewAccounts(cr_tests.TestClickReview):
 
     def test_check_hooks_versions_new(self):
         '''Test check_hooks_versions() - new hook'''
-        self.set_test_manifest("framework", "ubuntu-sdk-15.10")
+        self.set_test_manifest("framework", "ubuntu-sdk-15.04.1")
         self.set_test_account(self.default_appname, "accounts", dict())
         c = ClickReviewAccounts(self.test_name)
         c.check_hooks_versions()
@@ -107,7 +102,7 @@ class TestClickReviewAccounts(cr_tests.TestClickReview):
 
     def test_check_hooks_versions_disallowed_service(self):
         '''Test check_hooks_versions() - deprecated -service hook'''
-        self.set_test_manifest("framework", "ubuntu-sdk-16.04")
+        self.set_test_manifest("framework", "ubuntu-sdk-16.10")
         self.set_test_account(self.default_appname, "account-service", dict())
         c = ClickReviewAccounts(self.test_name)
         c.check_hooks_versions()
@@ -158,14 +153,11 @@ class TestClickReviewAccounts(cr_tests.TestClickReview):
               "provider": "becool"
             }
           ],
-          "plugins": [
-            {
-              "provider": "example",
+          "plugin": {
               "name": "Example site",
               "icon": "example.png",
               "qml": "qml_files"
-            }
-          ]
+          }
         }''')
         self.set_test_account(self.default_appname, "accounts", data)
         c = ClickReviewAccounts(self.test_name)
@@ -275,6 +267,30 @@ class TestClickReviewAccounts(cr_tests.TestClickReview):
         expected_counts = {'info': 4, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_application_snappy_1504(self):
+        '''Test check_application() - snappy 15.04'''
+        self.set_test_pkgfmt("snap", "15.04")
+        xml = self._stub_application()
+        # print(etree.tostring(xml))
+        self.set_test_account(self.default_appname, "account-application", xml)
+        c = ClickReviewAccounts(self.test_name)
+        c.check_application()
+        r = c.click_report
+        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_application_snappy_1604(self):
+        '''Test check_application() - snappy 16.04'''
+        self.set_test_pkgfmt("snap", "16.04")
+        xml = self._stub_application()
+        # print(etree.tostring(xml))
+        self.set_test_account(self.default_appname, "account-application", xml)
+        c = ClickReviewAccounts(self.test_name)
+        c.check_application()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_application_not_specified(self):
         '''Test check_application() - not specified'''
         c = ClickReviewAccounts(self.test_name)
