@@ -20,11 +20,6 @@ import clickreviews.cr_tests as cr_tests
 
 class TestClickReviewUrlDispatcher(cr_tests.TestClickReview):
     """Tests for the lint review tool."""
-    def setUp(self):
-        # Monkey patch various file access classes. stop() is handled with
-        # addCleanup in super()
-        cr_tests.mock_patch()
-        super()
 
     def test_check_required(self):
         '''Test check_required() - has protocol'''
@@ -260,3 +255,27 @@ class TestClickReviewUrlDispatcher(cr_tests.TestClickReview):
         r = c.click_report
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
+
+    def test_check_required_snappy_1504(self):
+        '''Test check_required() - has protocol - snappy 15.04'''
+        self.set_test_pkgfmt("snap", "15.04")
+        self.set_test_url_dispatcher(self.default_appname,
+                                     key="protocol",
+                                     value="some-protocol")
+        c = ClickReviewUrlDispatcher(self.test_name)
+        c.check_required()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_required_snappy_1604(self):
+        '''Test check_required() - has protocol - snappy 16.04'''
+        self.set_test_pkgfmt("snap", "16.04")
+        self.set_test_url_dispatcher(self.default_appname,
+                                     key="protocol",
+                                     value="some-protocol")
+        c = ClickReviewUrlDispatcher(self.test_name)
+        c.check_required()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
